# coding: utf-8

"""
CompanyApi.py
Copyright 2015 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class CompanyApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def companies_cin_get(self, cin, **kwargs):
        """
        Company Detail
        Returns a Company based on a single company identification number (cin)

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.companies_cin_get(cin, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str cin: cin of the company to fetch (required)
        :return: CompanyDetail
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cin']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method companies_cin_get" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'cin' is set
        if ('cin' not in params) or (params['cin'] is None):
            raise ValueError("Missing the required parameter `cin` when"
                             " calling `companies_cin_get`")

        resource_path = '/companies/{cin}'.replace('{format}', 'json')
        method = 'GET'

        path_params = {}
        if 'cin' in params:
            path_params['cin'] = params['cin']

        query_params = {}

        header_params = {}

        form_params = {}
        files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['api_key']

        response = self.api_client.call_api(resource_path, method,
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=files,
                                            response_type='CompanyDetail',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def companies_cin_authorized_signatories_get(self, cin, **kwargs):
        """
        Authorized Signatories
        Returns the Authorized Signatories which includes the Directors given a Company's CIN

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.companies_cin_authorized_signatories_get(cin, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str cin: cin of the company to fetch (required)
        :return: list[AuthorizedSignatory]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cin']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method companies_cin_authorized_signatories_get" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'cin' is set
        if ('cin' not in params) or (params['cin'] is None):
            raise ValueError("Missing the required parameter `cin` "
                             "when calling `companies_cin_authorized_signatories_get`")

        resource_path = '/companies/{cin}/authorizedSignatories'.replace('{format}', 'json')
        method = 'GET'

        path_params = {}
        if 'cin' in params:
            path_params['cin'] = params['cin']

        query_params = {}

        header_params = {}

        form_params = {}
        files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['api_key']

        response = self.api_client.call_api(resource_path, method,
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=files,
                                            response_type='list[AuthorizedSignatory]',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def companies_cin_charges_get(self, cin, **kwargs):
        """
        Charges
        Returns the Charge details given a Company's CIN

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.companies_cin_charges_get(cin, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str cin: cin of the company to fetch (required)
        :return: list[Charge]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cin']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method companies_cin_charges_get" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'cin' is set
        if ('cin' not in params) or (params['cin'] is None):
            raise ValueError("Missing the required parameter `cin` when "
                             "calling `companies_cin_charges_get`")

        resource_path = '/companies/{cin}/charges'.replace('{format}', 'json')
        method = 'GET'

        path_params = {}
        if 'cin' in params:
            path_params['cin'] = params['cin']

        query_params = {}

        header_params = {}

        form_params = {}
        files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['api_key']

        response = self.api_client.call_api(resource_path, method,
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=files,
                                            response_type='list[Charge]',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response
